_SUPPORTED_CURRENCIES = {
   "Albanian lek": "ALL",
   "Danish krone": "DKK",
   "Lesotho loti": "LSL",
   "Samoan tālā": "WST",
   "Algerian dinar": "DZD",
   "Djiboutian franc": "DJF",
   "Malagasy ariary": "MGA",
   "Serbian dinar": "RSD",
   "Argentine peso": "ARS",
   "Dominican peso": "DOP",
   "Malawian kwacha": "MWK",
   "Singapore dollar": "SGD",
   "Armenian dram": "AMD",
   "Eastern Caribbean dollar": "XCD",
   "Malaysian ringgit": "MYR",
   "Solomon Islands dollar": "SBD",
   "Australian dollar": "AUD",
   "Euro": "EUR",
   "Mauritian rupee": "MUR",
   "South African rand": "ZAR",
   "Azerbaijani manat": "AZN",
   "Fijan dollar": "FJD",
   "Mexican peso": "MXN",
   "Sri Lankan rupee": "LKR",
   "Bahamian dollar": "BSD",
   "Gambian dalasi": "GMD",
   "Moroccan dirham": "MAD",
   "Surinamese dollar": "SRD",
   "Bahraini dinar": "BHD",
   "Georgian lari": "GEL",
   "Mozambican metical": "MZN",
   "Swedish krona": "SEK",
   "Bangladeshi taka": "BDT",
    #"Ghanaian cedi": 
   "GHS Namibian dollar": "NAD",
   "Swiss franc": "CHF",
   "Barbadian dollar": "BBD",
   "Guatemalan quetzal": "GTQ",
   "Nepalese rupee": "NPR",
   "New Taiwan dollar": "TWD",
   "Bhutanese ngultrum": "BTN",
   "Guinean franc": "GNF",
   "New Zealand dollar": "NZD",
   "Tajikistani somoni": "TJS",
   "Bolivian boliviano": "BOB",
   "Honduran lempira": "HNL",
   "Macedonian denar": "MKD",
   "Tanzanian shilling": "TZS",
   "Bosnia and Herzegovina convertible mark": "BAM",
   "Hong Kong dollar": "HKD",
   "Norwegian krone": "NOK",
   "Thai baht": "THB",
   "Botswana pula": "BWP",
   "Hungarian forint": "HUF",
   "Omani rial": "OMR",
   "Tongan paʻanga": "TOP",
   "Brunei dollar": "BND",
   "Indian rupee": "INR",
   "Pakistani rupee": "PKR",
   "Trinidad and Tobago dollar": "TTD",
   "Indonesian rupiah": "IDR",
   "Papua New Guinean kina": "PGK",
   "Tunisian dinar": "TND",
   "Israeli new shekel": "ILS",
   "Paraguayan guaraní": "PYG",
   "Turkish lira": "TRY",
   "Cape Verdean escudo": "CVE",
   "Jamaican dollar": "JMD",
   "Peruvian sol": "PEN",
   "Ugandan shilling": "UGX",
   "Japanese yen": "JPY",
   "Philippine peso": "PHP",
   "United Arab Emirates dirham": "AED",
   "Jordanian dollar": "JOD",
   "Polish złoty": "PLN",
   "British pound": "GBP",
   "Kazakhstani tenge": "KZT",
   "Qatari riyal": "QAR",
   "United States dollar": "USD",
   "Kenyan shilling": "KES",
   "Romanian leu": "RON",
   "Uruguayan peso": "UYU",
   "South Korean won": "KRW",
   "Russian ruble": "RUB",
   "Vanuatu vatu": "VUV",
   "Kuwaiti dinar": "KWD",
   "Rwandan franc": "RWF",
   "Vietnamese đồng": "VND",
}



#!/usr/bin/python

import sys
import getopt
import requests as r
from bs4 import BeautifulSoup as bs
from supported_currencies import _SUPPORTED_CURRENCIES as SC

#https://www.xe.com/currencyconverter/convert/?Amount=1&From=USD&To=PKR
_u = 'https://www.xe.com/currencyconverter/convert/?Amount=1&From={}&To={}'

def rate(from_curr, to_curr):
    res = r.get(_u.format(from_curr.upper(), to_curr.upper()))
    parsed = bs(res.content, 'html.parser')
    el = parsed.find('span', attrs={'class': 'faded-digits'})
    return float(el.parent.text.split()[0].replace(',',''))

def convert(from_curr, to_curr, amount):
    print( from_curr, to_curr, amount )
    r = rate(from_curr, to_curr)
    c = amount * r
    return c

def show_help():
    print('Usage: pyfrx <from_currency> <to_currency> [amount]')
    print('Example Output: {}'.format(rate('pkr', 'syp')))
    
def show_currencies():
    print('CURRENCIES')
    print('==========')

    for k,v in SC.items():
        print('\033[1m{}\033[0m {}'.format(v.upper(), k.upper()))

if __name__ == '__main__':
    opts, args = getopt.getopt(sys.argv[1:], 'ch',['currencies', 'help'])
    for opt in opts:
        if opt[0] in ['-h', '--help']:
            show_help()
            sys.exit(0)
        elif opt[0] in ['-c', '--currencies']:
            show_currencies()
            sys.exit(0)

    nargs = len(args)
    if nargs < 2 or nargs > 3:
        raise Exception('Please check usage.')

    if nargs == 2:
        ans = rate(args[0], args[1])
    elif nargs == 3:
        ans = convert(args[0], args[1], float(args[2]))

    print('\033[1mRESULT\033[0m {} {}'.format(ans, args[1].upper()))
